@@ -49,13 +49,13 @@ def main():
             settings.BUCKET = args.bucket_name
             logger.info(f'Overriding bucket name with {settings.BUCKET}')
 
-    dataset_timestamp = datetime.now().strftime("%Y-%m-%d")
     if args.dataset_name:
-        DATASET_NAME = slugify(f'{args.dataset_name}-{dataset_timestamp}')
+        DATASET_NAME = slugify(f'{args.dataset_name}')
     else:
         # NOTE
         # This could be set as a default on line 13, but this way we get to
         # inform the user what is happening.
+        dataset_timestamp = datetime.now().strftime("%Y-%m-%d")
         logger.warning(f'Dataset name required. Setting dataset name to {dataset_timestamp}')
         DATASET_NAME = dataset_timestamp
 
