@@ -19,6 +19,7 @@ from tasq_cli.db import UploadsDatabase
 
 logger = None
 
+
 def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_path):
     # TODO only tested on unix systems
     file_path, file_name = os.path.split(file_name_with_path)
@@ -34,6 +35,10 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
         # if file is png, jpg, or jpeg - rotate
         if ext in ['png', 'jpg', 'jpeg']:
             image = Image.open(infile)
+            # Remove alpha channel for JPEG images
+            if ext in ['jpg', 'jpeg']:
+                image = image.convert('RGB')
+
             transposed_image = ImageOps.exif_transpose(image)
             transposed_image.save(image_wrapper, ('JPEG' if ext == 'jpg' else ext))
         else:
